@@ -12,7 +12,7 @@ from sklearn.neighbors import NearestNeighbors
 import copy
 import os
 from scipy.interpolate import UnivariateSpline
-import importlib
+from importlib.resources import files, as_file
 
 class estimator():
     '''
@@ -118,8 +118,8 @@ class estimator():
             if self.dim <= 3:
                 self.version = 1
             #self.model_path = 'trained_states/{}d/{}d_{}.ckpt'.format(self.dim, self.dim, self.num_point)
-            model_resources = importlib.resources.files(deep_density_estimation)
-            self.model_path = importlib.resources.as_file(model_resources / 'trained_states' / '{}d'.format(self.dim) / '{}d_{}.ckpt'.format(self.dim, self.num_point))
+            model_resources = files(deep_density_estimation)
+            self.model_path = as_file(model_resources / 'trained_states' / '{}d'.format(self.dim) / '{}d_{}.ckpt'.format(self.dim, self.num_point))
             assert os.path.exists(self.model_path+'.index'), 'could not find model {}'.format(self.model_path)
         
         self.batch_size = batch_size
